/******************************************************************************

                               Copyright (c) 2010
                            Lantiq Deutschland GmbH
                     Am Campeon 3; 85579 Neubiberg, Germany

  For licensing information, see the file 'LICENSE' in the root folder of
  this software module.

******************************************************************************/
#ifndef _COC_PMD_H_
#define _COC_PMD_H_

/**
   \addtogroup LQ_PMD
   @{
*/

/*=============================================================================*/
/* PMCU IOCTL DEFINES                                                          */
/*=============================================================================*/
/** Set a given module into a specific power state

   \param IFX_PMCU_MODULE_STATE_t* Pointer to a
    \ref IFX_PMCU_MODULE_STATE_t structure.

   \return Returns value as follows:
     - IFX_SUCCESS: if successful
     - IFX_ERROR: in case of an error

   \code
   IFX_PMCU_MODULE_STATE_t param;
   param.pmcuModule=IFX_PMCU_MODULE_CPU;
   param.pmcuModuleNr=0;
   param.pmcuState=IFX_PMCU_STATE_D0;
   ioctl(fd, IFX_PMCU_STATE_REQ, &param);
   \endcode
*/
#define IFX_PMCU_STATE_REQ  0


/** Get the current power state from a given module
   \param IFX_PMCU_MODULE_STATE_t* Pointer to a
    \ref IFX_PMCU_MODULE_STATE_t structure.

   \return Returns value as follows:
     - IFX_SUCCESS: if successful
     - IFX_ERROR: in case of an error

   \code
   IFX_PMCU_MODULE_STATE_t param;
   param.pmcuModule=IFX_PMCU_MODULE_CPU;
   param.pmcuModuleNr=0;
   param.pmcuState=IFX_PMCU_STATE_INVALID;
   ioctl(fd, IFX_PMCU_STATE_GET, &param);
   \endcode
*/
#define IFX_PMCU_STATE_GET  1


/*=============================================================================*/
/* PMCU ENUMERATION                                                                                                                */
/*=============================================================================*/
/** IFX_PMCU_MODULE_t
   Definition of the modules identifier
 */
typedef enum
{
   IFX_PMCU_MODULE_PMCU       = 0,
   IFX_PMCU_MODULE_CPU        = 1,
   IFX_PMCU_MODULE_ETH        = 2,
   IFX_PMCU_MODULE_USB        = 3,
   IFX_PMCU_MODULE_DSL        = 4,
   IFX_PMCU_MODULE_WLAN       = 5,
   IFX_PMCU_MODULE_DECT       = 6,
   IFX_PMCU_MODULE_FXS        = 7,
   IFX_PMCU_MODULE_FXO        = 8,
   IFX_PMCU_MODULE_VE         = 9,
   IFX_PMCU_MODULE_PPE        = 10,
   IFX_PMCU_MODULE_SWITCH     = 11,
   IFX_PMCU_MODULE_UART       = 12,
   IFX_PMCU_MODULE_SPI        = 13,
   IFX_PMCU_MODULE_SDIO       = 14,
   IFX_PMCU_MODULE_PCI        = 15,
   IFX_PMCU_MODULE_VLYNQ      = 16,
   IFX_PMCU_MODULE_DEU        = 17,
   IFX_PMCU_MODULE_CPU_PS     = 18,
   IFX_PMCU_MODULE_GPTC       = 19,
   IFX_PMCU_MODULE_USIF_UART  = 20,    /* VR9 usage */
   IFX_PMCU_MODULE_USIF_SPI   = 21,    /* VR9 usage */
   IFX_PMCU_MODULE_PCIE       = 22,    /* VR9 usage */
   IFX_PMCU_MODULE_ID_MAX     = 23,
} IFX_PMCU_MODULE_t;


/** IFX_PMCU_STATE_t
      Definition of power management state
*/
typedef enum
{
   /* ATTENTION:  Keep in mind that this list correspond to the ifx_pmcu_stateMap[][] array. 
                  If you have to change this list for any reason, ifx_pmcu_stateMap[][] must be adapted too. */

   /** State Invalid. */
   IFX_PMCU_STATE_INVALID = 0,
   /** State D0. Fully on */
   IFX_PMCU_STATE_D0 = 1,
   /** State D1. Device dependent */
   IFX_PMCU_STATE_D1 = 2,
   /** State D2. Device dependent */
   IFX_PMCU_STATE_D2 = 3,
   /** State D3. Off */
   IFX_PMCU_STATE_D3 = 4,
   /** don't care state */
   IFX_PMCU_STATE_D0D3 = 5,
} IFX_PMCU_STATE_t;



/** IFX_PMCU_RETURN_t
   Return value for PMCU functions and callbacks
*/
typedef enum
{
   /** Operation success */
   IFX_PMCU_RETURN_SUCCESS = 0,
   /** Operation denied */
   IFX_PMCU_RETURN_DENIED  = 1,
   /** Error condition */
   IFX_PMCU_RETURN_ERROR   = 2,
} IFX_PMCU_RETURN_t;


/*=============================================================================*/
/* PMCU STRUCTURES                                                             */
/*=============================================================================*/
/** 
    Structure hold the module-ID, the moduleSub-ID and the PowerState of one module.
*/
typedef struct _IFX_PMCU_MODULE_STATE_t
{
   /** Module identifier */
   IFX_PMCU_MODULE_t pmcuModule;
   /** instance identification of a Module; values 0,1,2,..... (0=first instance) */
   unsigned char     pmcuModuleNr;
   /** Module PowerState */
   IFX_PMCU_STATE_t  pmcuState;
} IFX_PMCU_MODULE_STATE_t;

/*@}*/

#endif   /* _COC_PMD_H_ */
